@@ -2,6 +2,7 @@ import os
 import shutil
 import tempfile
 
+import django
 from django.conf import settings
 from django.contrib.staticfiles import finders, storage
 from django.test import TestCase
@@ -22,6 +23,10 @@ def assertRaisesRegex(self, *args, **kwargs):
     return getattr(self, attr)(*args, **kwargs)
 
 
+def is_at_least_django_15():
+    return django.VERSION[0] >= 1 and django.VERSION[1] >= 5
+
+
 def is_glob2_available():
     try:
         import glob2
